==> haskell-vector-algorithms-0.7.0.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.7.0.1
id: vector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP
key: vector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP
license: BSD3
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for vector arrays
category: Data
author: Dan Doel
exposed: True
indefinite: False
exposed-modules:
    Data.Vector.Algorithms.AmericanFlag Data.Vector.Algorithms.Heap
    Data.Vector.Algorithms.Insertion Data.Vector.Algorithms.Intro
    Data.Vector.Algorithms.Merge Data.Vector.Algorithms.Optimal
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
abi: 20be0bc6e88cd27702622527898b03d0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vector-algorithms-0.7.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/vector-algorithms-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vector-algorithms-0.7.0.1
hs-libraries: HSvector-algorithms-0.7.0.1-IlgMkkQzf7kBLgtLlabzVP
include-dirs: /usr/lib/ghc-8.2.2/site-local/vector-algorithms-0.7.0.1/include
depends:
    base-4.10.1.0 vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    primitive-0.6.2.0-EI3NK1Xfv9zEcRtyXK2EwZ bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
             primitive-0.6.2.0-EI3NK1Xfv9zEcRtyXK2EwZ=8f45321f6a36e57e226bf2d17d6dafd0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.7.0.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.7.0.1
id: vector-algorithms-0.7.0.1-5mphjIH0bWI4CUpg2N3vz8
key: vector-algorithms-0.7.0.1-5mphjIH0bWI4CUpg2N3vz8
license: BSD3
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for vector arrays
category: Data
author: Dan Doel
exposed: True
indefinite: False
exposed-modules:
    Data.Vector.Algorithms.AmericanFlag Data.Vector.Algorithms.Heap
    Data.Vector.Algorithms.Insertion Data.Vector.Algorithms.Intro
    Data.Vector.Algorithms.Merge Data.Vector.Algorithms.Optimal
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
abi: ad66154cc9578718da070aabcd54c55c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vector-algorithms-0.7.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/vector-algorithms-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vector-algorithms-0.7.0.1
hs-libraries: HSvector-algorithms-0.7.0.1-5mphjIH0bWI4CUpg2N3vz8
include-dirs: /usr/lib/ghc-8.2.2/site-local/vector-algorithms-0.7.0.1/include
depends:
    base-4.10.1.0 vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
